@@ -4,7 +4,7 @@ import datetime
 import io
 from abc import ABCMeta, abstractmethod
 from pathlib import Path
-from typing import Any
+from typing import Any, get_args
 
 import matplotlib.pyplot as plt
 from matplotlib import colors, gridspec
@@ -12,7 +12,6 @@ from matplotlib.axes import Axes
 from matplotlib.colorbar import Colorbar
 from matplotlib.figure import Figure
 from matplotlib.ticker import MaxNLocator
-from typing_extensions import get_args
 
 import pygenomeviz
 from pygenomeviz.config import ASSETS_FILES, TEMPLATE_HTML_FILE, LiteralTypes
@@ -80,11 +79,11 @@ class GenomeVizBase(metaclass=ABCMeta):
     def _check_init_values(self) -> None:
         """Check initial values"""
         if self.align_type not in get_args(LiteralTypes.ALIGN_TYPE):
-            err_msg = f"Invalid align type '{self.align_type}'."
+            err_msg = f"{self.align_type=} is invalid."
             raise ValueError(err_msg)
 
         if self.tick_style not in get_args(LiteralTypes.TICK_STYLE):
-            err_msg = f"Invalid tick type '{self.tick_style}'."
+            err_msg = f"{self.tick_style=} is invalid."
             raise ValueError(err_msg)
 
     def _get_track_offset(self, track: Track) -> int:
@@ -144,10 +143,10 @@ class GenomeVizBase(metaclass=ABCMeta):
                 return target_link_track
             else:
                 err_msg = "LinkTrack is not found between target feature tracks "
-                err_msg += f"(`{feature_track_name1}` and '{feature_track_name2}')"
+                err_msg += f"({feature_track_name1=}, {feature_track_name2=})"
                 raise ValueError(err_msg)
         else:
-            err_msg = f"`{feature_track_name1}` and '{feature_track_name2}' "
+            err_msg = f"{feature_track_name1=} and {feature_track_name2=} "
             err_msg += "are not adjacent feature tracks."
             raise ValueError(err_msg)
 
@@ -175,8 +174,9 @@ class GenomeVizBase(metaclass=ABCMeta):
             Target track
         """
         name2track = {t.name: t for t in self.get_tracks()}
-        if track_name not in name2track.keys():
-            err_msg = f"track.name='{track_name}' is not found."
+        track_names = name2track.keys()
+        if track_name not in track_names:
+            err_msg = f"{track_name=} is not found ({track_names=})."
             raise ValueError(err_msg)
         return name2track[track_name]
 
@@ -407,7 +407,7 @@ class GenomeViz(GenomeVizBase):
             Track label size
         labelcolor : str, optional
             Track label color
-        labelmargin : flaot, optional
+        labelmargin : float, optional
             Track label margin
         linewidth : int, optional
             Track line width
@@ -488,9 +488,8 @@ class GenomeViz(GenomeVizBase):
         size_ratio : float, optional
             Link size ratio to track
         patch_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to link Patch object.
-            See matplotlib API document for detailed parameters
-            (https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html)
+            Patch properties (e.g. `dict(fc="red", ec="black", lw=0.5, ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         link_track = self._get_link_track(track_link1[0], track_link2[0])
         tracks = [t.name for t in self.get_tracks()]
