@@ -1,11 +1,10 @@
 from __future__ import annotations
 
 import math
-from typing import Any, Callable
+from typing import Any, Callable, Literal
 
 from Bio.SeqFeature import SeqFeature
 from matplotlib.axes import Axes
-from typing_extensions import Literal
 
 from pygenomeviz.config import LiteralTypes
 from pygenomeviz.feature import ExonFeature, Feature
@@ -227,7 +226,7 @@ class FeatureTrack(Track):
             if raise_error_on_false:
                 err_msg = f"'{self.name}' track start-end range must be "
                 err_msg += f"'{self.start} <= start <= end <= {self.end}' "
-                err_msg += f"(start={start}, end={end} is invalid)"
+                err_msg += f"({start=}, {end=} is invalid)"
                 raise ValueError(err_msg)
             return False
 
@@ -253,7 +252,7 @@ class FeatureTrack(Track):
         if name in [t.name for t in self.subtracks]:
             raise ValueError(f"subtrack.name='{name}' is already exists.")
         if position not in ("above", "below"):
-            raise ValueError(f"position='{position}' is invalid ('above'|'below').")
+            raise ValueError(f"{position=} is invalid ('above'|'below').")
 
         subtrack = FeatureSubTrack(
             name, self.size, self.spines, subtrack_ratio, position
@@ -303,9 +302,8 @@ class FeatureTrack(Track):
         ymargin : float, optional
             Sublabel y-margin
         sublabel_kws: dict[str, Any] | None, optional
-            Optional keyword arguments to pass to Axes.text method for sublabel.
-            See matplotlib API document for detailed parameters
-            (https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.text.html)
+            Text properties (e.g. `dict(size=12, color="red", ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.text.html>
         """
         # Sublabel text setting (e.g. '0 - 1000 bp')
         default_text = f"{self.start} - {self.end} bp"
@@ -317,7 +315,7 @@ class FeatureTrack(Track):
         vpos, hpos = position.split("-")
         vpos_types, hpos_types = ("top", "bottom"), ("left", "center", "right")
         if vpos not in vpos_types or hpos not in hpos_types:
-            err_msg = f"position='{position}' is invalid pattern. "
+            err_msg = f"{position=} is invalid pattern. "
             err_msg += "position must be '[top|bottom]-[left|center|right]'"
             raise ValueError(err_msg)
         vpos2y = {"top": 1 + ymargin, "bottom": -1 - ymargin}
@@ -384,9 +382,8 @@ class FeatureTrack(Track):
         size_ratio : float, optional
             Feature size ratio to track
         patch_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to feature Patch object.
-            See matplotlib API document for detailed parameters
-            (https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html)
+            Patch properties (e.g. `fc="red", ec="black", lw=0.5, ...`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         # Check if start & end positions are within appropriate track range
         self._within_valid_range(start, end, raise_error_on_false=True)
@@ -473,16 +470,14 @@ class FeatureTrack(Track):
         exon_labels: list[str] | None, optional
             Exon labels. Array length must be same as `exon_regions`.
         exon_label_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to Axes.text method for exon label.
-            Use this option when plotting both Feature & Exon labels.
-            See matplotlib API document for detailed parameters
-            (https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.text.html)
+            Text properties (e.g. `dict(size=12, color="red", ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.text.html>
         patch_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to exon feature Patch object.
-            See matplotlib API document for detailed parameters
-            (https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html)
+            Exon patch properties (e.g. `dict(fc="red", ec="black", lw=0.5, ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         intron_patch_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to intron feature Patch object.
+            Intron patch properties (e.g. `dict(ec="red", lw=2, ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         # Check if start & end positions are within appropriate track range
         for (exon_start, exon_end) in exon_regions:
@@ -584,9 +579,8 @@ class FeatureTrack(Track):
         size_ratio : float, optional
             Feature size ratio to track
         patch_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to feature Patch object.
-            See matplotlib API document for detailed parameters
-            (https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html)
+            Patch properties (e.g. `dict(fc="red", ec="black", lw=0.5, ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         target_features = gbk.extract_features(
             feature_type, None, False, allow_partial, pseudogene
@@ -699,11 +693,11 @@ class FeatureTrack(Track):
         size_ratio : float, optional
             Feature size ratio to track
         patch_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to feature Patch object.
-            See matplotlib API document for detailed parameters
-            (https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html)
+            Patch properties (e.g. `dict(fc="red", ec="black", lw=0.5, ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         intron_patch_kws : dict[str, Any] | None, optional
-            Optional keyword arguments to pass to intron feature Patch object.
+            Intron patch properties (e.g. `dict(ec="red", lw=0.5, ...)`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
         """
         # Extract target features
         if parse_exon_intron:
