@@ -45,7 +45,7 @@ def load_example_gff(
     """
     # Check specified filename exists or not
     if filename not in EXAMPLE_GFF_FILES:
-        err_msg = f"filename='{filename}' not found."
+        err_msg = f"{filename=} not found."
         raise ValueError(err_msg)
 
     # Cache local directory
@@ -220,6 +220,35 @@ class ColorCycler:
     def __new__(cls, n: int | None = None) -> str:
         """Get hexcolor cyclically from cmap by counter or user specified number
 
+        `ColorCycler()` works same as `ColorCycler.get_color()` (syntactic sugar)
+
+        Parameters
+        ----------
+        n : int | None, optional
+            Number for color cycle. If None, counter class variable is used.
+
+        Returns
+        -------
+        hexcolor : str
+            Cyclic hexcolor string
+        """
+        return cls.get_color(n)
+
+    @classmethod
+    def reset_cycle(cls) -> None:
+        """Reset cycle counter"""
+        cls.counter = 0
+
+    @classmethod
+    def set_cmap(cls, name: str) -> None:
+        """Set colormap (Default: `tab10`)"""
+        cls.cmap = plt.get_cmap(name)
+        cls.counter = 0
+
+    @classmethod
+    def get_color(cls, n: int | None = None) -> str:
+        """Get hexcolor cyclically from cmap by counter or user specified number
+
         Parameters
         ----------
         n : int | None, optional
@@ -235,17 +264,6 @@ class ColorCycler:
             cls.counter += 1
         return to_hex(cls.cmap(n % cls.cmap.N), keep_alpha=True)
 
-    @classmethod
-    def reset_cycle(cls) -> None:
-        """Reset cycle counter"""
-        cls.counter = 0
-
-    @classmethod
-    def set_cmap(cls, name: str) -> None:
-        """Set colormap (Default: `tab10`)"""
-        cls.cmap = plt.get_cmap(name)
-        cls.counter = 0
-
     @classmethod
     def get_color_list(cls, n: int | None = None) -> list[str]:
         """Get hexcolor list of colormap
@@ -266,6 +284,6 @@ class ColorCycler:
         elif n > 0:
             cmap_idx_list = [int(i) for i in np.linspace(0, cls.cmap.N, n)]
         else:
-            raise ValueError(f"n={n} is invalid number (Must be 'n > 0').")
+            raise ValueError(f"{n=} is invalid number (Must be 'n > 0').")
 
         return [to_hex(cls.cmap(i), keep_alpha=True) for i in cmap_idx_list]
